pub enum JsError {
Eval {
func: &'static str,
error: Arc<EvalError>,
},
Threw {
func: &'static str,
},
}Expand description
An error related to the execution of a javascript operation
Variants
Eval
Error occurred during dioxus evalution. If this occurs, it usually mean your js is not valid or the wrong type was returned from your js function
Threw
A js function that threw a value during execution. The actual error value is logged on the js side as a warning.